@@ -79,6 +79,12 @@ int dap_listlen = (256 * (15 + 7));
 				 */
 #endif
 #endif
+#ifdef DAP_TOOLONG
+int dap_toolong = DAP_TOOLONG;
+#else
+int dap_toolong = 10;		/* max # times to print "string too long" message */
+#endif
+
 #ifdef DAP_STRLEN
 int dap_strlen = DAP_STRLEN;
 #else
