@@ -141,6 +141,12 @@ static void initdo(dataobs *dato)
     }
 }
 
+/* the following variables are for determining endianness */
+static double testd; /* a double, half of whose contents will be converted to an... */
+static unsigned int *ptesti; /* unsigned int to see if they are
+			      /* zero (mantissa) or not (exponent and sign
+			       */
+
 int main(int argc, char **argv)
 {
   char *lstname;		/* name of .lst file */
@@ -148,7 +154,6 @@ int main(int argc, char **argv)
   char *errname;		/* name of .err file */
   int len;		/* length of lstname, logname, errname */
   int v;			/* index to variables */
-  double testd;           /* to check endianness */
 
   dap_dapname = argv[0];
   len = strlen(argv[0]);
@@ -210,14 +215,17 @@ int main(int argc, char **argv)
       dosave.do_str[v] = NULL;
     }
   dap_ono = 0;
-  testd = -2.0;
-  if (!(*((int *) &testd)))
-    {
+  testd = -2.0; /* this should have the sign bit set and non-zero exponent, but
+		   /* zero mantissa
+		    */
+  ptesti = (int *) &testd; /* *ptesti is the low order word of testd */
+  if (!(*ptesti))
+    { /* if that's zero, then the sign and exponent are in the high-order word */
       dap_dbllow = 0;
       dap_dblhigh = 1;
     }
   else
-    {
+    { /* else they're in the low-order word */
       dap_dbllow = 1;
       dap_dblhigh = 0;
     }
