@@ -278,7 +278,8 @@ void sort(char *fname, char *varlist, char *modifiers)
   dap_free(dsrt0, "");
 }
 
-static void printhead(char **formstr, char *fname, int *varv, int nvar)
+/* Print header for function "print" */
+static void printhead(char **formstr, int space, char *fname, int *varv, int nvar)
 {
   int v;
   int d;
@@ -296,64 +297,116 @@ static void printhead(char **formstr, char *fname, int *varv, int nvar)
       title(ttext);
     }
   dap_head((int *) NULL, 0);
-  fprintf(dap_lst, "  Obs ");
+  if (space == ' ')
+    fprintf(dap_lst, "  Obs ");
   for (v = 0; v < nvar; v++)
     {
+      if (space != ' ' && !strcmp(dap_obs[0].do_nam[varv[v]], "_type_"))
+	continue;
       if (dap_obs[0].do_len[varv[v]] <= 0)
-	fprintf(dap_lst, "%12s ", dap_obs[0].do_nam[varv[v]]);
+	{
+	  if (space == ' ')
+	    fprintf(dap_lst, "%12s", dap_obs[0].do_nam[varv[v]]);
+	  else
+	    fprintf(dap_lst, "%s", dap_obs[0].do_nam[varv[v]]);
+	}
       else
 	fprintf(dap_lst, formstr[v], dap_obs[0].do_nam[varv[v]]);
+      if (v < nvar - 1)
+	putc(space, dap_lst);
     }
   putc('\n', dap_lst);
-  fprintf(dap_lst, "----- ");
-  for (v = 0; v < nvar; v++)
+  if (space == ' ')
     {
-      for (d = 0; dap_obs[0].do_nam[varv[v]][d]; d++)
-	putc('-', dap_lst);
-      if (dap_obs[0].do_len[varv[v]] <= 0)	/* DBL or INT */
+      fprintf(dap_lst, "----- ");
+      for (v = 0; v < nvar; v++)
 	{
-	  while (d < 12)
+	  for (d = 0; dap_obs[0].do_nam[varv[v]][d]; d++)
+	    putc('-', dap_lst);
+	  if (dap_obs[0].do_len[varv[v]] <= 0)	/* DBL or INT */
 	    {
-	      putc('-', dap_lst);
-	      d++;
+	      while (d < 12)
+		{
+		  putc('-', dap_lst);
+		  d++;
+		}
 	    }
-	}
-      else
-	{
-	  while (d < dap_obs[0].do_len[varv[v]])
+	  else
 	    {
-	      putc('-', dap_lst);
-	      d++;
+	      while (d < dap_obs[0].do_len[varv[v]])
+		{
+		  putc('-', dap_lst);
+		  d++;
+		}
 	    }
+	  putc(' ', dap_lst);
 	}
-      putc(' ', dap_lst);
+      putc('\n', dap_lst);
     }
-  putc('\n', dap_lst);
   if (!wastitle)
     title(NULL);
   dap_free(ttext, "");
 }
 
+/* Print values in dataset. If varlist is NULL or "" or "\t" or ",", print values
+ * of all variables, otherwise just print those of named variables.
+ * If the variables in varlist are separated by spaces, then output
+ * contains value of _type_ variable and the observation number.
+ * Otherwise, the variables must be separated by tabs or commas and
+ * the value of _type_ variable and the observation number are omitted.
+ * No special handling is performed for strings containing tabs or commas.
+ */
 void print(char fname[], char *varlist)
 {
-  int *varv;
-  int nvar;
-  char *formmem;
-  char **formstr;
-  int v;
-  int lenstr;
+  char *varlist1; /* copy of varlist, changing tabs to spaces if necessary */
+  int space; /* space character for output: space, tab, or comma */
+  int *varv; /* vector of indices for variables */
+  int nvar; /* number of variables to print */
+  int typen; /* index of type variable in varv */
+  char *formmem; /* memory for formats */
+  char **formstr; /* format string */
+  int v; /* index to varlist and to varv */
+  int lenstr; /* length of string variable */
   int obn;
 
   varv = (int *) dap_malloc(sizeof(int) * dap_maxvar, "");
   inset(fname);
+  space = ' ';
   if (varlist && varlist[0])
     {
+      varlist1 = (char *) dap_malloc(strlen(varlist) + 1, "");
+      for (v = 0; varlist[v]; v++)
+	{
+	  if (varlist[v] == '\t' || varlist[v] == ',')
+	    {
+	      varlist1[v] = ' ';
+	      if (space == ' ')
+		space = varlist[v];
+	      else if (space != varlist[v])
+		{
+		  fputs("(print) variable list contains more than one type of separator\n",
+			dap_err);
+		  exit(1);
+		}
+	    }
+	  else
+	    varlist1[v] = varlist[v];
+	}
+      varlist1[v] = '\0';
       if ((varv[0] = dap_varnum("_type_")) < 0)
 	{
 	  fputs("(print) Missing _type_ variable.\n", dap_err);
 	  exit(1);
 	}
-      nvar = 1 + dap_list(varlist, varv + 1, dap_maxvar - 1);
+      typen = varv[0];
+      nvar = 1 + dap_list(varlist1, varv + 1, dap_maxvar - 1);
+      if (nvar == 1) /* there were no variables, just the separator */
+	{
+	  nvar = dap_obs[0].do_nvar;
+	  for (v = 0; v < nvar; v++)
+	    varv[v] = v;
+	}
+      dap_free(varlist1, "");
     }
   else
     {
@@ -372,35 +425,46 @@ void print(char fname[], char *varlist)
 	  lenstr = strlen(dap_obs[0].do_nam[varv[v]]);
 	  if (lenstr < 12)
 	    lenstr = 12;
-	  sprintf(formstr[v], "%%%dd ", lenstr);
+	  if (space != ' ')
+	    lenstr = 0;
+	  sprintf(formstr[v], "%%%dd", lenstr);
 	}
       else if (dap_obs[0].do_len[varv[v]] == DBL)
 	{
 	  lenstr = strlen(dap_obs[0].do_nam[varv[v]]);
 	  if (lenstr < 12)
 	    lenstr = 12;
-	  sprintf(formstr[v], "%%%dg ", lenstr);
+	  if (space != ' ')
+	    lenstr = 0;
+	  sprintf(formstr[v], "%%%dg", lenstr);
 	}
       else
 	{
 	  lenstr = strlen(dap_obs[0].do_nam[varv[v]]);
 	  if (lenstr < dap_obs[0].do_len[varv[v]])
 	    lenstr = dap_obs[0].do_len[varv[v]];
-	  sprintf(formstr[v], "%%-%ds ", lenstr);
+	  if (space != ' ')
+	    lenstr = 0;
+	  sprintf(formstr[v], "%%-%ds", lenstr);
 	}
     }
-  printhead(formstr, fname, varv, nvar);
+  printhead(formstr, space, fname, varv, nvar);
   for (obn = 1; step(); )
     {
-      fprintf(dap_lst, "%5d ", obn);
+      if (space == ' ')
+	fprintf(dap_lst, "%5d ", obn);
       for (v = 0; v < nvar; v++)
 	{
+	  if (space != ' ' && varv[v] == typen)
+	    continue;
 	  if (dap_obs[0].do_len[varv[v]] == INT)
 	    fprintf(dap_lst, formstr[v], dap_obs[0].do_int[varv[v]]);
 	  else if (dap_obs[0].do_len[varv[v]] == DBL)
 	    fprintf(dap_lst, formstr[v], dap_obs[0].do_dbl[varv[v]]);
 	  else
 	    fprintf(dap_lst, formstr[v], dap_obs[0].do_str[varv[v]]);
+	  if (v < nvar - 1)
+	    putc(space, dap_lst);
 	}
       putc('\n', dap_lst);
       obn++;
@@ -1883,7 +1947,7 @@ void split(char *fname, char *varlist, char *classvalvars)
       fprintf(dap_err, "(split) No value variable specified: %s\n", classvalvars);
       exit(1);
     }
-  var = (int *) dap_malloc((strlen(varlist) + 1) / 2, "");	/* more than necessary */
+  var = (int *) dap_malloc(sizeof(int) * ((strlen(varlist) + 1) / 2), ""); /* more than necessary */
   varname = dap_malloc(strlen(varlist) + 1, "");	/* longest possible name */
   skiplist = dap_malloc(strlen(varlist) + 2, "");	/* prepare to eliminate variables */
   strcpy(skiplist, "!");		/* if outset second parameter starts with '!'... */
