@@ -43,6 +43,8 @@ extern int dap_maxtxt;
 extern int dap_maxfont;
 
 /* Parameters for I/O */
+extern int dap_toolong;         /* number of times to allow printing of "string too long"
+				 * warning on input */
 extern int dap_linelen;		/* max number of char for input line (+1 for null) */
 extern int dap_outreport;	/* report multiples of this number of lines written */
 
