@@ -82,7 +82,7 @@ static void yaxis(pict *p, double miny, double maxy, tick ytick[], int nyticks,
        * numerical labels
        */
       strcpy(tpos, "cb ");	/* coordinates give center, bottom point of axis label */
-      xlaboff = 0.25 * p->pict_fs * ((double) (labslen + 3)) * ytick[nyticks].tick_len;
+      xlaboff = 0.25 * p->pict_fs * ((double) (labslen + 6)) * fabs(ytick[nyticks].tick_len);
       txtang = side * 90.0;
     }
   else if (ytick[nyticks].tick_num < miny)	/* label at bottom */
@@ -107,7 +107,7 @@ static void yaxis(pict *p, double miny, double maxy, tick ytick[], int nyticks,
       pict_point(p, ypos, ytick[nyticks].tick_num);
       if (side > 0.0 || marks)
 	pict_text(p, ytick[nyticks].tick_lab,
-		  ypos - 2.0 * (1.5 * side - 0.5) * ytick[nyticks].tick_len,
+		  ypos - (4.5 * side - 0.5) * fabs(ytick[nyticks].tick_len),
 		  ytick[nyticks].tick_num, 0.0, npos);
     }
   pict_point(p, ypos, miny);
@@ -148,7 +148,7 @@ static void xaxis(pict *p, double minx, double maxx, tick xtick[], int nxticks,
 	  tpos[1] = 'b';
 	  npos[1] = 'b';
 	}
-      ylaboff = p->pict_fs * xtick[nxticks].tick_len;	/* make room for label */
+      ylaboff = fabs(p->pict_fs * xtick[nxticks].tick_len); /* make room for label */
     }
   else if (xtick[nxticks].tick_num < minx)	/* axis label at left end */
     {
@@ -172,7 +172,7 @@ static void xaxis(pict *p, double minx, double maxx, tick xtick[], int nxticks,
       pict_point(p, xtick[nxticks].tick_num, xpos);
       if (side > 0.0 || marks)
 	pict_text(p, xtick[nxticks].tick_lab, xtick[nxticks].tick_num,
-		  xpos - 2.0 * side * xtick[nxticks].tick_len, 0.0, npos);
+		  xpos - 2.0 * side * fabs(xtick[nxticks].tick_len), 0.0, npos);
     }
   pict_point(p, minx, xpos);
   pict_point(p, ypos, xpos);	/* end up at ypos, xpos */
@@ -347,7 +347,7 @@ static void ticks(
 		  double min,		/* coordinate of lowest valued tick */
 		  double max,		/* coordinate of highest valued tick */
 		  int ndigs,		/* number of digits for tick label */
-		  double ticklen,		/* length of tick line */
+		  double ticklen,	/* length of tick line */
 		  int nticks,		/* number of ticks requested not including axis label */
 		  double labpos,		/* position of axis label */
 		  char *alab,		/* axis label */
@@ -709,8 +709,8 @@ double pict_autoaxes(pict *p, char *xlab, char *ylab, char *axspec,
       fprintf(dap_err, "(pict_autoaxes) Too many y-ticks (%d)\n", nyticks);
       exit(1);
     }
-  xticklen = 2.0;
-  yticklen = 2.0;
+  xticklen = -2.0;
+  yticklen = -2.0;
   if (autopos)
     {
       if (autopos == PORTRAIT)
