@@ -1,4 +1,4 @@
-/*  Copyright (C) 2003, 2004 Free Software Foundation, Inc.
+/*  Copyright (C) 2003, 2004, 2005 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -1036,7 +1036,7 @@ void univariatetrans(char *step, FILE *dapfile)
 		}
 	      fprintf(dapfile, "normal(\"%s\", \"%s\", \"", setname, varname);
 	      copylist(step, "by", dapfile);
-	      fprintf(dapfile, "\", %d);\n", MAXPICTS);
+	      fprintf(dapfile, "\", %d);\n", (plot ? MAXPICTS : 0));
 	      if (plot)
 		fputs("_sbspictpage_[_sbsnpicts_++] = 1;\n", dapfile);
 	    }
